@@ -9,13 +9,13 @@ def trim(func):
 
 curr_dir = path.dirname(path.realpath(__file__))
 
-with open(path.join(curr_dir, 'js/mathlib.js')) as f:
+with open(path.join(curr_dir, 'mathlib.js')) as f:
     mathlib = f.read()
 
-with open(path.join(curr_dir, 'js/scramble.js')) as f:
+with open(path.join(curr_dir, 'scramble.js')) as f:
     scramble = f.read()
 
-with open(path.join(curr_dir, 'js/sq1.js')) as f:
+with open(path.join(curr_dir, 'sq1.js')) as f:
     sq1 = f.read()
 
 sq1scrambler   = execjs.compile(mathlib + scramble + sq1)
